cluscata_liking: Perform a cluster analysis of subjects on CATA/liking...

View source: R/cluscata_liking.R

cluscata_likingR Documentation

Perform a cluster analysis of subjects on CATA/liking combination

Description

Clustering of subjects (blocks) from combination of CATA and liking experiments.

Usage

cluscata_liking(Data, nblo, NameBlocks=NULL, NameVar=NULL,  Itermax=30,
                       Graph_dend=TRUE, Graph_bar=TRUE,
                        printlevel=FALSE,gpmax=min(6, nblo-1))

Arguments

Data

data frame or matrix where the blocks of variables (attributes) are merged horizontally thanks to combinCATALiking function

nblo

numerical. Number of blocks (subjects).

NameBlocks

string vector. Name of each block (subject). Length must be equal to the number of blocks. If NULL, the names are S1,...Sm. Default: NULL

NameVar

string vector. Name of each variable (attribute, the same names for each subject). Length must be equal to the number of attributes. If NULL, the colnames of the first block are taken. Default: NULL

Itermax

numerical. Maximum of iteration for the partitioning algorithm. Default:30

Graph_dend

logical. Should the dendrogram be plotted? Default: TRUE

Graph_bar

logical. Should the barplot of the difference of the criterion and the barplot of the overall homogeneity at each merging step of the hierarchical algorithm be plotted? Default: TRUE

printlevel

logical. Print the number of remaining levels during the hierarchical clustering algorithm? Default: FALSE

gpmax

logical. What is maximum number of clusters to consider? Default: min(6, nblo-2)

Value

Each partitionK contains a list for each number of clusters of the partition, K=1 to gpmax with:

  • group: the clustering partition after consolidation.

  • compromise: the compromise of each cluster

  • dist_all_cluster: the distance between each subject and each cluster compromise

  • criterion: the CLUSCATA-liking criterion error

  • param: parameters called

  • type: parameter passed to other functions

There is also at the end of the list:

  • dend: The CLUSCATA dendrogram

  • cutree_k: the partition obtained by cutting the dendrogram in K clusters (before consolidation).

  • diff_crit_ng: variation of criterion when a merging is done before consolidation (and after)

  • param: parameters called

  • type: parameter passed to other functions

References

Vigneau, E., Cariou, V., Giacalone, D., Berget, I., & Llobell, F. (2022). Combining hedonic information and CATA description for consumer segmentation. Food Quality and Preference, 95, 104358.

See Also

plot.cluscata_liking, summary.cluscata_liking , combinCATALiking

Examples

data(cata_ryebread)
data(liking_ryebread)
cataliking=combinCATALiking(cata_ryebread, liking_ryebread)

#with only 40 subjects
resclustcatal=cluscata_liking(Data=cataliking[,1:(40*14)], nblo=40, gpmax=5)
plot(resclustcatal, cata_ryebread[,1:(40*14)], liking_ryebread[,1:40])



ClustBlock documentation built on March 24, 2026, 9:08 a.m.