combinCATALiking: Combination of CATA and liking data for CLUSCATA-liking

View source: R/combinCATALiking.R

combinCATALikingR Documentation

Combination of CATA and liking data for CLUSCATA-liking

Description

For CLUSCATA-liking, this preprocessing is needed.

Usage

combinCATALiking(cata, liking, center=TRUE, scale=FALSE)

Arguments

cata

data frame or matrix where the blocks of binary variables are merged horizontally. If you have a different format, see change_cata_format

liking

data frame or matrix where the products are in rows and the assessors in columns

center

Centering of consumer liking. Default: TRUE

scale

Scaling of consumer liking. Default: FALSE

Value

Combined data

References

Vigneau, E., Cariou, V., Giacalone, D., Berget, I., & Llobell, F. (2022). Combining hedonic information and CATA description for consumer segmentation. Food Quality and Preference, 95, 104358.

See Also

cluscata_liking

Examples

data(cata_ryebread)
data(liking_ryebread)
cataliking=combinCATALiking(cata_ryebread, liking_ryebread)


ClustBlock documentation built on March 24, 2026, 9:08 a.m.