Learn R Programming

ClustBlock (version 6.1.0)

croissant: Croissant JAR and liking data

Description

Croissant JAR and liking data

Usage

data(croissant)

Arguments

Format

Just-About-Right (JAR) and liking data. A data frame with one row per subject-product combination. The first column identifies the subjects, the second column identifies the products, the following columns contain the JAR evaluations on a 5-point scale, and the last column contains the overall liking scores.

References

Llobell, F. & Guksch, T. (2026). Beyond penalty analysis: Joint clustering of consumers using JAR and liking data. EuroSense, Oslo, Norway.

Examples

Run this code
data(croissant)

Run the code above in your browser using DataLab