plot.cluscata_liking: Displays the CLUSCATA-liking graphs

View source: R/plot.cluscata_liking.R

plot.cluscata_likingR Documentation

Displays the CLUSCATA-liking graphs

Description

This function plots dendrogram, variation of the merging criterion, weights and CATATIS map of each cluster

Usage

## S3 method for class 'cluscata_liking'
plot(x, DataCata, Dataliking, ngroups=NULL,
 center=TRUE, scale=FALSE,
 sep_graphs=TRUE, Graph_dend=TRUE, Graph_bar=FALSE,
  cex=1,  xlimfreq=c(0,0.6), ylimchangelik=c(-2, 2), ...)

Arguments

x

object of class 'cluscata_liking'.

DataCata

data frame or matrix where the blocks of binary variables are merged horizontally. If you have a different format, see change_cata_format

Dataliking

data frame or matrix where the products are in rows and the assessors in columns

ngroups

number of groups to consider. Default: recommended number of clusters

center

Centering of consumer liking. Default: TRUE

scale

Scaling of consumer liking. Default: FALSE

sep_graphs

logical. Should cata and liking data analyzed separately first?

Graph_dend

logical. Should the dendrogram be plotted? Default: TRUE

Graph_bar

logical. Should the barplot of the difference of the criterion and the barplot of the overall homogeneity at each merging step of the hierarchical algorithm be plotted? Also available after consolidation if Noise_cluster=FALSE. Default: FALSE

cex

numerical. Numeric character expansion factor; multiplied by par("cex") yields the final character size. NULL and NA are equivalent to 1.0.

xlimfreq

vector of 2 values. Used for the graph of the frequency of citations

ylimchangelik

vector of 2 values. Used for the graphs of change in liking

...

further arguments passed to or from other methods

Value

the CLUSCATA-liking graphs

See Also

cluscata_liking , summary.cluscata_liking

Examples


data(cata_ryebread)
data(liking_ryebread)
cataliking=combinCATALiking(cata_ryebread, liking_ryebread)

#with only 40 subjects
resclustcatal=cluscata_liking(Data=cataliking[,1:(40*14)], nblo=40, gpmax=5)
plot(resclustcatal, cata_ryebread[,1:(40*14)], liking_ryebread[,1:40],
xlimfreq=c(0,0.6),  ylimchangelik=c(-2, 2))




ClustBlock documentation built on March 24, 2026, 9:08 a.m.