View source: R/combinCATALiking.R
| combinCATALiking | R Documentation |
For CLUSCATA-liking, this preprocessing is needed.
combinCATALiking(cata, liking, center=TRUE, scale=FALSE)
cata |
data frame or matrix where the blocks of binary variables are merged horizontally. If you have a different format, see |
liking |
data frame or matrix where the products are in rows and the assessors in columns |
center |
Centering of consumer liking. Default: TRUE |
scale |
Scaling of consumer liking. Default: FALSE |
Combined data
Vigneau, E., Cariou, V., Giacalone, D., Berget, I., & Llobell, F. (2022). Combining hedonic information and CATA description for consumer segmentation. Food Quality and Preference, 95, 104358.
cluscata_liking
data(cata_ryebread)
data(liking_ryebread)
cataliking=combinCATALiking(cata_ryebread, liking_ryebread)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.