| mixclustatis | R Documentation |
Perform cluster analysis of variables in context of quantitative, qualitative or mixed datasets with MixCluStatis.
mixclustatis(Data, quanti=NULL,quali=NULL,Noise_cluster=FALSE,
Itermax=20, printlevel=FALSE, Graph_dend=TRUE, Graph_bar=TRUE,
gpmax=min(6, length(quali)+length(quanti)-1), rhoparam = NULL)
Data |
data frame or matrix. Correspond to all the data (variables are columns) |
quanti |
numerical vector. The number of the columns containing quantitative variables. |
quali |
numerical vector. The number of the columns containing qualitative variables. |
Noise_cluster |
logical. Should a noise cluster be computed? Default: FALSE |
Itermax |
numerical. Maximum of iteration for the partitioning algorithm. Default: 30 |
printlevel |
logical. Print the number of remaining levels during the hierarchical clustering algorithm? Default: FALSE |
Graph_dend |
logical. Should the dendrogram be plotted? Default: TRUE |
Graph_bar |
logical. Should the barplot of the difference of the criterion and the barplot of the overall homogeneity at each merging step of the hierarchical algorithm be plotted? Default: TRUE |
gpmax |
logical. What is maximum number of clusters to consider? Default: min(6, number of variables -2) |
rhoparam |
numerical or vector. What is the threshold for the noise cluster? Between 0 and 1, high value can imply lot of vatriables set aside. If NULL, automatic threshold is computed. Can be different for each group (in this case, provide a vector) |
Each partitionK contains a list for each number of clusters of the partition, K=1 to gpmax with:
group: the clustering partition of variables after consolidation. If Noise_cluster=TRUE, some variables could be in the noise cluster ("K+1")
rho: the threshold(s) for the noise cluster (computed or input parameter)
homogeneity: homogeneity index (
rv_with_compromise: RV coefficient of each variable with its cluster compromise
weights: weight associated with each variable in its cluster
comp_RV: RV coefficient between the compromises associated with the various clusters
compromise: the W compromise of each cluster
coord: the coordinates of objects of each cluster
inertia: percentage of total variance explained by each axis for each cluster
rv_all_cluster: the RV coefficient between each variable and each cluster compromise
criterion: the CLUSTATIS criterion error
param: parameters called in the consolidation
type: parameter passed to other functions
There is also at the end of the list:
dend: The CLUSTATIS dendrogram
cutree_k: the partition obtained by cutting the dendrogram for K clusters (before consolidation).
overall_homogeneity_ng: percentage of overall homogeneity by number of clusters before consolidation (and after if there is no noise cluster)
diff_crit_ng: variation of criterion when a merging is done before consolidation (and after if there is no noise cluster)
param: parameters called
type: parameter passed to other functions
Paper submitted: Llobell, F., Abdi, H., Eslami, A. (2026). Clustering of categorical and mixed data variables around latent variables.
Llobell, F., Cariou, V., Vigneau, E., Labenne, A., & Qannari, E. M. (2018). Analysis and clustering of multiblock datasets by means of the STATIS and CLUSTATIS methods. Application to sensometrics. Food Quality and Preference, in Press.
Llobell, F., Vigneau, E., Qannari, E. M. (2019). Clustering datasets by means of CLUSTATIS with identification of atypical datasets. Application to sensometrics. Food Quality and Preference, 75, 97-104.
Llobell, F., & Qannari, E. M. (2020). CLUSTATIS: Cluster analysis of blocks of variables. Electronic Journal of Applied Statistical Analysis, 13(2).
clustatis, plot.clustatis, summary.clustatis
data("wine", package = "FactoMineR")
res=mixclustatis(wine, quanti = 3:29, quali = 1:2)
summary(res)
plot(res, Graph_groups = FALSE, Graph_weights = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.